==> haskell-data-default-instances-base-0.1.0.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-base
version:              0.1.0.2
visibility:           public
id:                   data-default-instances-base-0.1.0.2-IKeXGcdgiV38iGtz1zLkEn
key:                  data-default-instances-base-0.1.0.2-IKeXGcdgiV38iGtz1zLkEn
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in base
category:             Data
abi:                  79c081f833981a901ca9e8145b6241f3
exposed:              True
exposed-modules:      Data.Default.Instances.Base
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-base
hs-libraries:
    HSdata-default-instances-base-0.1.0.2-IKeXGcdgiV38iGtz1zLkEn

depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-base/html/data-default-instances-base.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-base-0.1.0.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-base
version:              0.1.0.3
visibility:           public
id:                   data-default-instances-base-0.1.0.3-GU67BT6x2ka1GDwREJjJNM
key:                  data-default-instances-base-0.1.0.3-GU67BT6x2ka1GDwREJjJNM
license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in base
description:
    This module reëxports the '\''Data.Default.Class.Default'\'' instances from the
    "Data.Default.Class" module.

category:             Data
abi:                  713ae705c8fed117099f3daf4d2aa29d
exposed:              True
exposed-modules:      Data.Default.Instances.Base
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-base-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-base
hs-libraries:
    HSdata-default-instances-base-0.1.0.3-GU67BT6x2ka1GDwREJjJNM

depends:
    base-4.17.2.1 data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-base/html/data-default-instances-base.haddock

haddock-html:         /usr/share/doc/haskell-data-default-instances-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
